@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_ec2._jsii
@@ -17,9 +17,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-elasticloadbalancingv2-actions",
-    "1.62.0",
+    "1.64.1",
     __name__[0:-6],
-    "aws-elasticloadbalancingv2-actions@1.62.0.jsii.tgz",
+    "aws-elasticloadbalancingv2-actions@1.64.1.jsii.tgz",
 )
 
 __all__ = [
